<!-- Naming convention: [TYPE][SCOPE] Name of the PR
• TYPE can be FEATURE, FIX, HOTFIX, REFACTORING, CONFIG, DOC)
• SCOPE can be ETL, MODEL, RECOMMENDER , API, INFRA, PIPELINE
e.g. [FEATURE][MODEL] Integrate PI data -->

## DESCRIPTION
<!-- Describe what your PR does, why and how -->



## CHECK-LIST

- [ ] I have added the necessary documentation
- [ ] I have added tests on my functions
- [ ] No additional warning in the logs


## COMPLEXITY

### Complexity level

<!-- Choose a complexity level -->

- [ ] `★` Simple modification
- [ ] `★★` New feature or change in functionality
- [ ] `★★★` Global impact
- [ ] `★★★★` Critical impact

### Dependencies

<!-- Does the PR depends on other PRs? -->



## TESTING

<!-- What has been done to verify the changes? -->
<!-- Are there any untested edge cases or concerns? -->
<!-- Any changes on previously existing tests and why? -->